@@ -2,11 +2,11 @@ from __future__ import annotations
 
 from .common import Amplitude, Csys
 from .constraints import Bc, Constraint, PredefinedField
-from .containers import FEM
-from .elements import Connector, ConnectorSection, Elem, FemSection, Mass, Spring
+from .elements import Connector, Elem, Mass, Spring
 from .interactions import Interaction, InteractionProperty
 from .loads import Load, LoadCase
 from .outputs import FieldOutput, HistOutput
+from .sections import ConnectorSection, FemSection
 from .sets import FemSet
 from .steps import Step
 from .surfaces import Surface
@@ -24,7 +24,6 @@ __all__ = [
     "Constraint",
     "PredefinedField",
     "FemSet",
-    "FEM",
     "Mass",
     "HistOutput",
     "FieldOutput",
